==> vtigercrm-5.2.1.tgz: modules/Contacts/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : Contacts
*  Language     : Francais
*  Version      : 5.1.0 GA*  Created Date : 2009-06-23 21:36:13 
*  Last change  : 2009-07-21 00:49:17
*  Author       : french-vtiger.fr 
*  License      : GPL

***********************************************************/

$mod_strings = array (
		'LBL_MODULE_NAME' => 'Contacts',
		'LBL_INVITEE' => 'Supérieur hiérarchique',
		'LBL_MODULE_TITLE' => 'Contact : accueil',
		'LBL_SEARCH_FORM_TITLE' => 'Rechercher contacts',
		'LBL_LIST_FORM_TITLE' => 'Liste contacts',
		'LBL_NEW_FORM_TITLE' => 'Nouveau contact',
		'LBL_CONTACT_OPP_FORM_TITLE' => 'Contact-Affaire :',
		'LBL_CONTACT' => 'Contact :',
		'LBL_LIST_NAME' => 'Nom',
		'LBL_LIST_LAST_NAME' => 'Nom',
		'LBL_LIST_FIRST_NAME' => 'Prénom',
		'LBL_LIST_CONTACT_NAME' => 'Nom',
		'LBL_LIST_TITLE' => 'Fonction',
		'LBL_LIST_ACCOUNT_NAME' => 'Compte',
		'LBL_LIST_EMAIL_ADDRESS' => 'Email',
		'LBL_LIST_PHONE' => 'Téléphone',
		'LBL_LIST_CONTACT_ROLE' => 'Rôle',
		'db_last_name' => LBL_LIST_LAST_NAME,
		'db_first_name' => LBL_LIST_FIRST_NAME,
		'db_title' => LBL_LIST_TITLE,
		'db_email1' => LBL_LIST_EMAIL_ADDRESS,
		'db_email2' => LBL_LIST_EMAIL_ADDRESS,
		'LBL_EXISTING_CONTACT' => 'Un contact existant à été utilisé',
		'LBL_CREATED_CONTACT' => 'Un nouveau contact à été créé',
		'LBL_EXISTING_ACCOUNT' => 'Un compte existant à été créé',
		'LBL_CREATED_ACCOUNT' => 'Un compte à été créé',
		'LBL_CREATED_CALL' => 'Un appel à été créé',
		'LBL_CREATED_MEETING' => 'Un rendez-vous à été créé',
		'LBL_ADDMORE_BUSINESSCARD' => 'Ajouter une autre carte de visite',
		'LBL_BUSINESSCARD' => 'Carte de visite',
		'LBL_NAME' => 'Nom :',
		'LBL_CONTACT_NAME' => 'Nom contact :',
		'LBL_CONTACT_INFORMATION' => 'Détail contact ',
		'LBL_CUSTOM_INFORMATION' => 'Informations personnalisées',
		'LBL_FIRST_NAME' => 'Prénom :',
		'LBL_OFFICE_PHONE' => 'Téléphone (bureau) :',
		'LBL_ACCOUNT_NAME' => 'Compte :',
		'LBL_ANY_PHONE' => 'Téléphone (alt.) :',
		'LBL_PHONE' => 'Téléphone :',
		'LBL_LAST_NAME' => 'Nom :',
		'LBL_MOBILE_PHONE' => 'Téléphone (mobile)',
		'LBL_HOME_PHONE' => 'Téléphone (domicile) :',
		'LBL_LEAD_SOURCE' => 'Origine :',
		'LBL_OTHER_PHONE' => 'Téléphone (alt.) :',
		'LBL_FAX_PHONE' => 'Fax :',
		'LBL_TITLE' => 'Fonction :',
		'LBL_DEPARTMENT' => 'Service/Division :',
		'LBL_BIRTHDATE' => 'Anniversaire :',
		'LBL_EMAIL_ADDRESS' => 'Email :',
		'LBL_OTHER_EMAIL_ADDRESS' => 'Email (alt.) :',
		'LBL_ANY_EMAIL' => 'Email (al.) :',
		'LBL_REPORTS_TO' => 'Supérieur hiérarchique :',
		'LBL_ASSISTANT' => 'Assistant :',
		'LBL_YAHOO_ID' => 'Yahoo ID :',
		'LBL_ASSISTANT_PHONE' => 'Téléphone (assistant) :',
		'LBL_DO_NOT_CALL' => 'Ne pas appeler :',
		'LBL_EMAIL_OPT_OUT' => 'Ne pas contacter par email :',
		'LBL_PRIMARY_ADDRESS' => 'Adresse (principale) :',
		'LBL_ALTERNATE_ADDRESS' => 'Adresse (alt.) :',
		'LBL_ANY_ADDRESS' => 'Adresse (alt.) :',
		'LBL_CITY' => 'Ville :',
		'LBL_STATE' => 'Département :',
		'LBL_POSTAL_CODE' => 'Code postal :',
		'LBL_COUNTRY' => 'Pays :',
		'LBL_DESCRIPTION_INFORMATION' => 'Informations complémentaires',
		'LBL_IMAGE_INFORMATION' => 'Image/Photo du contact',
		'LBL_ADDRESS_INFORMATION' => 'Adresse',
		'LBL_DESCRIPTION' => 'Description :',
		'LBL_CONTACT_ROLE' => 'Rôle :',
		'LBL_OPP_NAME' => 'Affaire :',
		'LBL_DUPLICATE' => 'Doublon possible',
		'MSG_DUPLICATE' => 'La création de ce contact peut engendrer un doublon. Vous pouvez soit choisir un contact dans la liste ci-dessous ou cliquer sur Créer nouveau contact pour continuer la création d\'un nouveau contact avec les données que vous venez d\'entrer.',
		'LNK_NEW_APPOINTMENT' => 'Nouveau rendez-vous',
		'LBL_ADD_BUSINESSCARD' => 'Ajouter carte de visite',
		'NTC_DELETE_CONFIRMATION' => 'Etes-vous certain de vouloir supprimer cet enregistrement ?',
		'NTC_REMOVE_CONFIRMATION' => 'Etes vous certain de vouloir retirer ce contact ?',
		'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION' => 'Etes-vous certain de vouloir retirer cet enregistrement du lien hiérarchique ?',
		'ERR_DELETE_RECORD' => 'Un numéro d\'enregistrement doit être spécifié pour supprimer ce contact.',
		'NTC_COPY_PRIMARY_ADDRESS' => 'Utiliser l\'adresse principale comme adresse alternative',
		'NTC_COPY_ALTERNATE_ADDRESS' => 'Utiliser l\'adresse alternative comme adresse principale',
		'LBL_SELECT_CONTACT' => 'Sélectionner contact',
		'LBL_GENERAL_INFORMATION' => 'Information',
		'LBL_NEW_POTENTIAL' => 'Nouvelle affaire',
		'LBL_POTENTIAL_TITLE' => 'Affaire',
		'LBL_NEW_TASK' => 'Nouvelle tâche',
		'LBL_TASK_TITLE' => 'Tâches',
		'LBL_NEW_CALL' => 'Nouvel appel',
		'LBL_CALL_TITLE' => 'Appels',
		'LBL_NEW_MEETING' => 'Nouveau rendez-vous',
		'LBL_MEETING_TITLE' => 'Rendez-vous',
		'LBL_NEW_EMAIL' => 'Nouvel email',
		'LBL_EMAIL_TITLE' => 'Emails',
		'LBL_NEW_NOTE' => 'Nouvelle note',
		'LBL_NOTE_TITLE' => 'Notes',
		'LBL_TOOL_FORM_TITLE' => 'Outils',
		'Salutation' => 'Salutation',
		'First Name' => 'Prénom',
		'Office Phone' => 'Téléphone (bureau)',
		'Last Name' => 'Nom',
		'Mobile' => 'Téléphone (mobile)',
		'Account Name' => 'Compte',
		'Home Phone' => 'Téléphone (domicile)',
		'Lead Source' => 'Origine',
		'Other Phone' => 'Téléphone (Alt.)',
		'Title' => 'Fonction',
		'Fax' => 'Fax',
		'Department' => 'Service/Division',
		'Birthdate' => 'Anniversaire',
		'Email' => 'Email',
		'Reports To' => 'Supérieur hiérarchique',
		'Assistant' => 'Assistant',
		'Yahoo Id' => 'Yahoo ID',
		'Assistant Phone' => 'Téléphone (assistant)',
		'Do Not Call' => 'Ne pas appeler',
		'Email Opt Out' => 'Ne pas contacter par email',
		'Assigned To' => 'Assigné à',
		'Campaign Source' => 'Campagne',
		'Reference' => 'Référent',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Mailing Street' => 'Adresse',
		'Other Street' => 'Adresse (alt.)',
		'Mailing City' => 'Ville',
		'Mailing State' => 'Département',
		'Mailing Zip' => 'Code postal',
		'Mailing Country' => 'Pays',
		'Mailing Po Box' => 'Boite postale',
		'Other Po Box' => 'Boite postale (alt.)',
		'Other City' => 'Ville (alt.)',
		'Other State' => 'Département (alt.)',
		'Other Zip' => 'Code postal (alt.)',
		'Other Country' => 'Pays (alt.)',
		'Contact Image' => 'Photo',
		'Description' => 'Description',
		'LBL_NEW_CONTACT' => 'Nouveau contact',
		'LBL_NEW_ACCOUNT' => 'Nouveau compte',
		'LBL_NOTE_SUBJECT' => 'Objet note :',
		'LBL_NOTE' => 'Note :',
		'LBL_WEBSITE' => 'Site Web :',
		'LBL_NEW_APPOINTMENT' => 'Nouveau rendez-vous',
		'LBL_SUBJECT' => 'Objet :',
		'LBL_START_DATE' => 'Date de début :',
		'LBL_START_TIME' => 'Heure de début :',
		'Portal User' => 'Accès portail de service',
		'LBL_CUSTOMER_PORTAL_INFORMATION' => 'Portail de service client',
		'Support Start Date' => 'Début assistance',
		'Support End Date' => 'Fin assistance',
		'Name' => 'Nom',
		'LBL_ALL' => 'Tout',
		'LBL_MAXIMUM_LIMIT_ERROR' => 'Désolé, le fichier que vous tentez de télécharger dépasse la taille limite. Veuillez réessayer avec un fichier dont la taille est inférieure à 800 000 bytes',
		'LBL_UPLOAD_ERROR' => 'Problème de téléchargement. Veuillez réessayer !',
		'LBL_IMAGE_ERROR' => 'Le fichier n\'est pas de type image (.gif, .jpg, .png)',
		'LBL_INVALID_IMAGE' => 'Fichier non valide ou vide.',
		'Notify Owner' => 'Notifier collaborateur assigné',
		'--None--' => '--Aucun--',
		'Mr.' => 'M',
		'Ms.' => 'Mme',
		'Mrs.' => 'Mlle',
		'Dr.' => 'Dr',
		'Prof.' => 'Prof',
		'Cold Call' => 'Appel direct',
		'Existing Customer' => 'Client existant',
		'Self Generated' => 'Auto généré',
		'Employee' => 'Employée',
		'Partner' => 'Partenaire',
		'Public Relations' => 'Relation publique',
		'Direct Mail' => 'Email direct',
		'Conference' => 'Conférence',
		'Trade Show' => 'Salon',
		'Web Site' => 'Site Web',
		'Word of mouth' => 'Bouche à oreille',
		'Other' => 'Autre',
		'User List' => 'Liste des collaborateurs',
		'Customer Portal Login Details' => 'Détail login portail client',
		'Dear' => 'Cher',
		'Your Customer Portal Login details are given below:' => 'Veuillez noter vos identifiants de connexion à notre portail de services :',
		'User Id :' => 'Nom d\'utilisateur :',
		'Password :' => 'Mot de passe :',
		'Please Login Here' => 'Veuillez vous connecter ici',
		'Note :' => 'Note :',
		'We suggest you to change your password after logging in first time' => 'Nous vous suggérons de changer votre mot de passe dès votre première connexion.',
		'Support Team' => 'L\'équipe support',
		'TITLE_AJAX_CSS_POPUP_CHAT' => 'Chat',
		'LBL_DUPLICATE_DATA_IN' => 'Dupliquer ',
		'LBL_DELETE' => 'Supprimer',
		'LBL_MERGE_SELECT' => 'Fusionner la sélection',
		'LBL_MERGE' => 'Fusionner',
		'LBL_MERGE_DATA_IN' => 'Fusionner les enregistrements',
		'LBL_ACTION' => 'Effet',
		'LBL_FIELDLISTS' => 'Liste des champs',
		'LBL_RECORD' => 'Enregistrement #',
'Contact Id' => 'N° Contact',
);
$mod_list_strings = array (
);
?>

==> vtigercrm-5.4.0.tgz: modules/Contacts/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : Contacts
*  Language     : French
*  Version      : 5.4.0 
*  License      : GPL
*  Author       : ABOnline solutions http://www.vtiger-crm.fr
***********************************************************/

$mod_strings = array (
		'LBL_MODULE_NAME' => 'Contacts',
		'LBL_INVITEE' => 'Supérieur hiérarchique',
		'LBL_MODULE_TITLE' => 'Contact : accueil',
		'LBL_SEARCH_FORM_TITLE' => 'Rechercher contacts',
		'LBL_LIST_FORM_TITLE' => 'Liste contacts',
		'LBL_NEW_FORM_TITLE' => 'Nouveau contact',
		'LBL_CONTACT_OPP_FORM_TITLE' => 'Contact-Affaire :',
		'LBL_CONTACT' => 'Contact :',
		'LBL_LIST_NAME' => 'Nom',
		'LBL_LIST_LAST_NAME' => 'Nom',
		'LBL_LIST_FIRST_NAME' => 'Prénom',
		'LBL_LIST_CONTACT_NAME' => 'Nom',
		'LBL_LIST_TITLE' => 'Fonction',
		'LBL_LIST_ACCOUNT_NAME' => 'Compte',
		'LBL_LIST_EMAIL_ADDRESS' => 'Email',
		'LBL_LIST_PHONE' => 'Téléphone',
		'LBL_LIST_CONTACT_ROLE' => 'Rôle',
		'db_last_name' => LBL_LIST_LAST_NAME,
		'db_first_name' => LBL_LIST_FIRST_NAME,
		'db_title' => LBL_LIST_TITLE,
		'db_email1' => LBL_LIST_EMAIL_ADDRESS,
		'db_email2' => LBL_LIST_EMAIL_ADDRESS,
		'LBL_EXISTING_CONTACT' => 'Un contact existant à été utilisé',
		'LBL_CREATED_CONTACT' => 'Un nouveau contact à été créé',
		'LBL_EXISTING_ACCOUNT' => 'Un compte existant à été créé',
		'LBL_CREATED_ACCOUNT' => 'Un compte à été créé',
		'LBL_CREATED_CALL' => 'Un appel à été créé',
		'LBL_CREATED_MEETING' => 'Un rendez-vous à été créé',
		'LBL_ADDMORE_BUSINESSCARD' => 'Ajouter une autre carte de visite',
		'LBL_BUSINESSCARD' => 'Carte de visite',
		'LBL_NAME' => 'Nom :',
		'LBL_CONTACT_NAME' => 'Nom contact :',
		'LBL_CONTACT_INFORMATION' => 'Détail contact ',
		'LBL_CUSTOM_INFORMATION' => 'Informations personnalisées',
		'LBL_FIRST_NAME' => 'Prénom :',
		'LBL_OFFICE_PHONE' => 'Téléphone (bureau) :',
		'LBL_ACCOUNT_NAME' => 'Compte :',
		'LBL_ANY_PHONE' => 'Téléphone (alt.) :',
		'LBL_PHONE' => 'Téléphone :',
		'LBL_LAST_NAME' => 'Nom :',
		'LBL_MOBILE_PHONE' => 'Téléphone (mobile)',
		'LBL_HOME_PHONE' => 'Téléphone (domicile) :',
		'LBL_LEAD_SOURCE' => 'Origine :',
		'LBL_OTHER_PHONE' => 'Téléphone (alt.) :',
		'LBL_FAX_PHONE' => 'Fax :',
		'LBL_TITLE' => 'Fonction :',
		'LBL_DEPARTMENT' => 'Service/Division :',
		'LBL_BIRTHDATE' => 'Anniversaire :',
		'LBL_EMAIL_ADDRESS' => 'Email :',
		'LBL_OTHER_EMAIL_ADDRESS' => 'Email (alt.) :',
		'LBL_ANY_EMAIL' => 'Email (al.) :',
		'LBL_REPORTS_TO' => 'Supérieur hiérarchique :',
		'LBL_ASSISTANT' => 'Assistant :',
		'LBL_YAHOO_ID' => 'Yahoo ID :',
		'LBL_ASSISTANT_PHONE' => 'Téléphone (assistant) :',
		'LBL_DO_NOT_CALL' => 'Ne pas appeler :',
		'LBL_EMAIL_OPT_OUT' => 'Ne pas contacter par email :',
		'LBL_PRIMARY_ADDRESS' => 'Adresse (principale) :',
		'LBL_ALTERNATE_ADDRESS' => 'Adresse (alt.) :',
		'LBL_ANY_ADDRESS' => 'Adresse (alt.) :',
		'LBL_CITY' => 'Ville :',
		'LBL_STATE' => 'Département :',
		'LBL_POSTAL_CODE' => 'Code postal :',
		'LBL_COUNTRY' => 'Pays :',
		'LBL_DESCRIPTION_INFORMATION' => 'Informations complémentaires',
		'LBL_IMAGE_INFORMATION' => 'Image/Photo du contact',
		'LBL_ADDRESS_INFORMATION' => 'Adresse',
		'LBL_DESCRIPTION' => 'Description :',
		'LBL_CONTACT_ROLE' => 'Rôle :',
		'LBL_OPP_NAME' => 'Affaire :',
		'LBL_DUPLICATE' => 'Doublon possible',
		'MSG_DUPLICATE' => 'La création de ce contact peut engendrer un doublon. Vous pouvez soit choisir un contact dans la liste ci-dessous ou cliquer sur Créer nouveau contact pour continuer la création d\'un nouveau contact avec les données que vous venez d\'entrer.',
		'LNK_NEW_APPOINTMENT' => 'Nouveau rendez-vous',
		'LBL_ADD_BUSINESSCARD' => 'Ajouter carte de visite',
		'NTC_DELETE_CONFIRMATION' => 'Etes-vous certain de vouloir supprimer cet enregistrement ?',
		'NTC_REMOVE_CONFIRMATION' => 'Etes vous certain de vouloir retirer ce contact ?',
		'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION' => 'Etes-vous certain de vouloir retirer cet enregistrement du lien hiérarchique ?',
		'ERR_DELETE_RECORD' => 'Un numéro d\'enregistrement doit être spécifié pour supprimer ce contact.',
		'NTC_COPY_PRIMARY_ADDRESS' => 'Utiliser l\'adresse principale comme adresse alternative',
		'NTC_COPY_ALTERNATE_ADDRESS' => 'Utiliser l\'adresse alternative comme adresse principale',
		'LBL_SELECT_CONTACT' => 'Sélectionner contact',
		'LBL_GENERAL_INFORMATION' => 'Information',
		'LBL_NEW_POTENTIAL' => 'Nouvelle affaire',
		'LBL_POTENTIAL_TITLE' => 'Affaire',
		'LBL_NEW_TASK' => 'Nouvelle tâche',
		'LBL_TASK_TITLE' => 'Tâches',
		'LBL_NEW_CALL' => 'Nouvel appel',
		'LBL_CALL_TITLE' => 'Appels',
		'LBL_NEW_MEETING' => 'Nouveau rendez-vous',
		'LBL_MEETING_TITLE' => 'Rendez-vous',
		'LBL_NEW_EMAIL' => 'Nouvel email',
		'LBL_EMAIL_TITLE' => 'Emails',
		'LBL_NEW_NOTE' => 'Nouvelle note',
		'LBL_NOTE_TITLE' => 'Notes',
		'LBL_TOOL_FORM_TITLE' => 'Outils',
		'Salutation' => 'Salutation',
		'First Name' => 'Prénom',
		'Office Phone' => 'Téléphone (bureau)',
		'Last Name' => 'Nom',
		'Mobile' => 'Téléphone (mobile)',
		'Account Name' => 'Compte',
		'Home Phone' => 'Téléphone (domicile)',
		'Lead Source' => 'Origine',
		'Other Phone' => 'Téléphone (Alt.)',
		'Title' => 'Fonction',
		'Fax' => 'Fax',
		'Department' => 'Service/Division',
		'Birthdate' => 'Anniversaire',
		'Email' => 'Email',
		'Reports To' => 'Supérieur hiérarchique',
		'Assistant' => 'Assistant',
		'Yahoo Id' => 'Yahoo ID',
		'Assistant Phone' => 'Téléphone (assistant)',
		'Do Not Call' => 'Ne pas appeler',
		'Email Opt Out' => 'Ne pas contacter par email',
		'Assigned To' => 'Assigné à',
		'Campaign Source' => 'Campagne',
		'Reference' => 'Référent',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Mailing Street' => 'Adresse',
		'Other Street' => 'Adresse (alt.)',
		'Mailing City' => 'Ville',
		'Mailing State' => 'Département',
		'Mailing Zip' => 'Code postal',
		'Mailing Country' => 'Pays',
		'Mailing Po Box' => 'Boite postale',
		'Other Po Box' => 'Boite postale (alt.)',
		'Other City' => 'Ville (alt.)',
		'Other State' => 'Département (alt.)',
		'Other Zip' => 'Code postal (alt.)',
		'Other Country' => 'Pays (alt.)',
		'Contact Image' => 'Photo',
		'Description' => 'Description',
		'LBL_NEW_CONTACT' => 'Nouveau contact',
		'LBL_NEW_ACCOUNT' => 'Nouveau compte',
		'LBL_NOTE_SUBJECT' => 'Objet note :',
		'LBL_NOTE' => 'Note :',
		'LBL_WEBSITE' => 'Site Web :',
		'LBL_NEW_APPOINTMENT' => 'Nouveau rendez-vous',
		'LBL_SUBJECT' => 'Objet :',
		'LBL_START_DATE' => 'Date de début :',
		'LBL_START_TIME' => 'Heure de début :',
		'Portal User' => 'Accès portail de service',
		'LBL_CUSTOMER_PORTAL_INFORMATION' => 'Portail de service client',
		'Support Start Date' => 'Début assistance',
		'Support End Date' => 'Fin assistance',
		'Name' => 'Nom',
		'LBL_ALL' => 'Tout',
		'LBL_MAXIMUM_LIMIT_ERROR' => 'Désolé, le fichier que vous tentez de télécharger dépasse la taille limite. Veuillez réessayer avec un fichier dont la taille est inférieure à 800 000 bytes',
		'LBL_UPLOAD_ERROR' => 'Problème de téléchargement. Veuillez réessayer !',
		'LBL_IMAGE_ERROR' => 'Le fichier n\'est pas de type image (.gif, .jpg, .png)',
		'LBL_INVALID_IMAGE' => 'Fichier non valide ou vide.',
		'Notify Owner' => 'Notifier collaborateur assigné',
		'--None--' => '--Aucun--',
		'Mr.' => 'M',
		'Ms.' => 'Mme',
		'Mrs.' => 'Mlle',
		'Dr.' => 'Dr',
		'Prof.' => 'Prof',
		'Cold Call' => 'Appel direct',
		'Existing Customer' => 'Client existant',
		'Self Generated' => 'Auto généré',
		'Employee' => 'Employée',
		'Partner' => 'Partenaire',
		'Public Relations' => 'Relation publique',
		'Direct Mail' => 'Email direct',
		'Conference' => 'Conférence',
		'Trade Show' => 'Salon',
		'Web Site' => 'Site Web',
		'Word of mouth' => 'Bouche à oreille',
		'Other' => 'Autre',
		'User List' => 'Liste des collaborateurs',
		'Customer Portal Login Details' => 'Détail login au portail client',
		'Dear' => 'Cher(ère)',
		'Your Customer Portal Login details are given below:' => 'Veuillez noter vos identifiants de connexion à notre portail de services :',
		'User Id :' => 'Nom d\'utilisateur :',
		'Password :' => 'Mot de passe :',
		'Please Login Here' => 'Veuillez vous connecter ici',
		'Note :' => 'Note :',
		'We suggest you to change your password after logging in first time' => 'Nous vous suggérons de modifier votre mot de passe dès votre première connexion.',
		'Support Team' => 'L\'équipe support',
		'TITLE_AJAX_CSS_POPUP_CHAT' => 'Chat',
		'LBL_DUPLICATE_DATA_IN' => 'Dupliquer ',
		'LBL_DELETE' => 'Supprimer',
		'LBL_MERGE_SELECT' => 'Fusionner la sélection',
		'LBL_MERGE' => 'Fusionner',
		'LBL_MERGE_DATA_IN' => 'Fusionner les enregistrements',
		'LBL_ACTION' => 'Action',
		'LBL_FIELDLISTS' => 'Liste des champs',
		'LBL_RECORD' => 'Enregistrement #',
		'Contact Id' => 'N° Contact',

);
$mod_list_strings = array (
);
?>
